# Code of Conduct

## Our Pledge

We are committed to providing a welcoming and inclusive environment for all contributors, regardless of background or identity.

## Our Standards

Examples of behavior that contributes to a positive environment:

- Using welcoming and inclusive language
- Being respectful of differing viewpoints and experiences
- Gracefully accepting constructive criticism
- Focusing on what is best for the community
- Showing empathy towards other community members

Examples of unacceptable behavior:

- Trolling, insulting/derogatory comments, and personal attacks
- Public or private harassment
- Publishing others' private information without permission
- Other conduct which could reasonably be considered inappropriate

## Our Responsibilities

Project maintainers are responsible for clarifying standards of acceptable behavior and are expected to take appropriate corrective action in response to unacceptable behavior.

## Scope

This Code of Conduct applies within all project spaces and when an individual is representing the project or its community.

## Enforcement

Instances of unacceptable behavior may be reported by contacting:

**Email**: patrick.roebuck@deepstudyai.com

All complaints will be reviewed and investigated promptly and fairly. The project team is obligated to maintain confidentiality regarding the reporter.

## Attribution

This Code of Conduct is adapted from the Contributor Covenant, version 2.0.
